@@ -1,13 +1,13 @@
-"""
-See LightDB docstring:
+"""See LightDB docstring:
 
 from LightDB import LightDB
 ---------------------
 
-:copyright: (c) 2021 by Fl1yd.
+:copyright: (c) 2021-2022 by Fl1yd.
 :license: MIT, see LICENSE for more details.
 """
 
-from .LightDB import LightDB
+__all__ = ["LightDB"]
+__version__ = "1.3"
 
-__version__ = "1.1"
\ No newline at end of file
+from .LightDB import LightDB
